@@ -32,10 +32,9 @@ def topasgraphsim():
 
             if drag.install_success == True:
                 python = sys.executable
-                args = "".join(sys.argv)
-                if args.endswith(".py") == False:
-                    args = args + ".py"
-                print(args)
+                args = os.path.join(
+                    os.path.dirname(os.path.realpath(__file__)), "topasgraphsim.py"
+                )
                 os.execl(python, python, args)
                 return
 
@@ -45,9 +44,9 @@ def topasgraphsim():
             except RuntimeError:
                 ProfileHandler().set_attribute("draganddrop", False)
                 python = sys.executable
-                args = "".join(sys.argv)
-                if args.endswith(".py") == False:
-                    args = args + ".py"
+                args = os.path.join(
+                    os.path.dirname(os.path.realpath(__file__)), "topasgraphsim.py"
+                )
                 os.execl(python, python, args)
                 return
         else:
